@@ -8,7 +8,8 @@ from httpx import Cookies, Timeout
 
 from .helpers import environment_reader
 
-logging.basicConfig(level=logging.INFO)
+logger = logging.getLogger('loop_communication')
+logging.getLogger("httpx").setLevel(logging.WARNING)
 
 SLEEP_TIME_ON_429 = 5
 MAX_RETRIES_ON_429 = 20
@@ -37,9 +38,9 @@ class LoopCommunicator():
         host: str = environment_reader.host(default='learning-loop.ai')
         self.ssl_cert_path = environment_reader.ssl_certificate_path()
         if self.ssl_cert_path:
-            logging.info('Using SSL certificate at %s', self.ssl_cert_path)
+            logger.info('Using SSL certificate at %s', self.ssl_cert_path)
         else:
-            logging.info('No SSL certificate path set')
+            logger.info('No SSL certificate path set')
         self.host: str = host
         self.username: str = environment_reader.username()
         self.password: str = environment_reader.password()
@@ -52,7 +53,7 @@ class LoopCommunicator():
         else:
             self.async_client = httpx.AsyncClient(base_url=self.base_url, timeout=Timeout(60.0))
 
-        logging.info('Loop interface initialized with base_url: %s / user: %s', self.base_url, self.username)
+        logger.info('Loop interface initialized with base_url: %s / user: %s', self.base_url, self.username)
 
     def websocket_url(self) -> str:
         return f'ws{"s" if "learning-loop.ai" in self.host else ""}://' + self.host
@@ -65,7 +66,7 @@ class LoopCommunicator():
             self.async_client.cookies.clear()
             response = await self.async_client.post('/api/login', data={'username': self.username, 'password': self.password})
             if response.status_code != 200:
-                logging.info('Login failed with response: %s', response)
+                logger.info('Login failed with response: %s', response)
                 raise LoopCommunicationException('Login failed with response: ' + str(response))
             self.async_client.cookies.update(response.cookies)
 
@@ -74,7 +75,7 @@ class LoopCommunicator():
 
         response = await self.async_client.post('/api/logout')
         if response.status_code != 200:
-            logging.info('Logout failed with response: %s', response)
+            logger.info('Logout failed with response: %s', response)
             raise LoopCommunicationException('Logout failed with response: ' + str(response))
         self.async_client.cookies.clear()
 
@@ -90,41 +91,41 @@ class LoopCommunicator():
         start_time = time.time()
         while True:
             try:
-                logging.info('Checking if backend is ready')
+                logger.info('Checking if backend is ready')
                 response = await self.get('/status', requires_login=False)
                 if response.status_code == 200:
                     return True
             except Exception:
-                logging.info('backend not ready yet.')
+                logger.info('backend not ready yet.')
             if timeout is not None and time.time() + 10 - start_time > timeout:
                 raise TimeoutError('Backend not ready within timeout')
             await asyncio.sleep(10)
 
-    async def retry_on_401(self, func: Callable[..., Awaitable[httpx.Response]], *args, **kwargs) -> httpx.Response:
+    async def _retry_on_401(self, func: Callable[..., Awaitable[httpx.Response]], *args, **kwargs) -> httpx.Response:
         response = await func(*args, **kwargs)
         if response.status_code == 401:
             await self.ensure_login(relogin=True)
             response = await func(*args, **kwargs)
         return response
 
-    async def get(self, path: str, requires_login: bool = True, api_prefix: str = '/api') -> httpx.Response:
+    async def get(self, path: str, requires_login: bool = True, api_prefix: str = '/api', timeout: int = 60) -> httpx.Response:
         if requires_login:
             await self.ensure_login()
-            return await self.retry_on_401(self._get, path, api_prefix)
+            return await self._retry_on_401(self._get, path, api_prefix, timeout)
         return await self._get(path, api_prefix)
 
     @retry_on_429
-    async def _get(self, path: str, api_prefix: str) -> httpx.Response:
-        return await self.async_client.get(api_prefix+path)
+    async def _get(self, path: str, api_prefix: str, timeout: int = 60) -> httpx.Response:
+        return await self.async_client.get(api_prefix+path, timeout=timeout)
 
-    async def put(self, path: str, files: Optional[List[str]] = None, requires_login: bool = True, api_prefix: str = '/api', **kwargs) -> httpx.Response:
+    async def put(self, path: str, files: Optional[List[str]] = None, requires_login: bool = True, api_prefix: str = '/api', timeout: int = 60, **kwargs) -> httpx.Response:
         if requires_login:
             await self.ensure_login()
-            return await self.retry_on_401(self._put, path, files, api_prefix, **kwargs)
-        return await self._put(path, files, api_prefix, **kwargs)
+            return await self._retry_on_401(self._put, path, files, api_prefix, timeout, **kwargs)
+        return await self._put(path, files, api_prefix, timeout, **kwargs)
 
     @retry_on_429
-    async def _put(self, path: str, files: Optional[List[str]], api_prefix: str, **kwargs) -> httpx.Response:
+    async def _put(self, path: str, files: Optional[List[str]], api_prefix: str, timeout: int = 60, **kwargs) -> httpx.Response:
         if files is None:
             return await self.async_client.put(api_prefix+path, **kwargs)
 
@@ -139,29 +140,29 @@ class LoopCommunicator():
 
         try:
             file_list = [('files', fh) for fh in file_handles]  # Use file handles
-            response = await self.async_client.put(api_prefix+path, files=file_list)
+            response = await self.async_client.put(api_prefix+path, files=file_list, timeout=timeout)
         finally:
             for fh in file_handles:
                 fh.close()  # Ensure all files are closed
 
         return response
 
-    async def post(self, path: str, requires_login: bool = True, api_prefix: str = '/api', **kwargs) -> httpx.Response:
+    async def post(self, path: str, requires_login: bool = True, api_prefix: str = '/api', timeout: int = 60, **kwargs) -> httpx.Response:
         if requires_login:
             await self.ensure_login()
-            return await self.retry_on_401(self._post, path, api_prefix, **kwargs)
+            return await self._retry_on_401(self._post, path, api_prefix, timeout, **kwargs)
         return await self._post(path, api_prefix, **kwargs)
 
     @retry_on_429
-    async def _post(self, path, api_prefix='/api', **kwargs) -> httpx.Response:
-        return await self.async_client.post(api_prefix+path, **kwargs)
+    async def _post(self, path, api_prefix='/api', timeout: int = 60, **kwargs) -> httpx.Response:
+        return await self.async_client.post(api_prefix+path, timeout=timeout, **kwargs)
 
-    async def delete(self, path: str, requires_login: bool = True, api_prefix: str = '/api', **kwargs) -> httpx.Response:
+    async def delete(self, path: str, requires_login: bool = True, api_prefix: str = '/api', timeout: int = 60, **kwargs) -> httpx.Response:
         if requires_login:
             await self.ensure_login()
-            return await self.retry_on_401(self._delete, path, api_prefix, **kwargs)
+            return await self._retry_on_401(self._delete, path, api_prefix, timeout, **kwargs)
         return await self._delete(path, api_prefix, **kwargs)
 
     @retry_on_429
-    async def _delete(self, path, api_prefix, **kwargs) -> httpx.Response:
-        return await self.async_client.delete(api_prefix+path, **kwargs)
+    async def _delete(self, path, api_prefix, timeout: int = 60, **kwargs) -> httpx.Response:
+        return await self.async_client.delete(api_prefix+path, timeout=timeout, **kwargs)
