@@ -6,8 +6,16 @@ import zipfile
 from glob import glob
 from typing import Callable
 
-from ..data_classes import (BoxDetection, ClassificationDetection, Detections, Point, PointDetection,
-                            SegmentationDetection, Shape)
+from ..data_classes import (
+    BoxDetection,
+    ClassificationDetection,
+    Detections,
+    Point,
+    PointDetection,
+    SegmentationDetection,
+    Shape,
+)
+from ..data_classes.image_metadata import ImageMetadata
 from ..loop_communication import LoopCommunicator
 
 
@@ -62,7 +70,7 @@ def _update_attribute_dict(obj: dict, **kwargs) -> None:
         obj[key] = value
 
 
-def get_dummy_detections():
+def get_dummy_detections() -> Detections:
     return Detections(
         box_detections=[
             BoxDetection(category_name='some_category_name', x=1, y=2, height=3, width=4,
@@ -78,3 +86,11 @@ def get_dummy_detections():
         classification_detections=[
             ClassificationDetection(category_name='some_category_name_4', model_name='some_model',
                                     confidence=.42, category_id='some_id_4')])
+
+
+def get_dummy_metadata() -> ImageMetadata:
+    detections = get_dummy_detections()
+    return ImageMetadata(box_detections=detections.box_detections,
+                         point_detections=detections.point_detections,
+                         segmentation_detections=detections.segmentation_detections,
+                         classification_detections=detections.classification_detections)
