@@ -6,13 +6,25 @@ import sys
 import time
 from abc import ABC, abstractmethod
 from dataclasses import asdict
-from typing import TYPE_CHECKING, Callable, Coroutine, Dict, List, Optional
+from typing import TYPE_CHECKING, Any, Callable, Coroutine, Dict, List, Optional
 
 from fastapi.encoders import jsonable_encoder
 
-from ..data_classes import Context, Errors, PretrainedModel, Training, TrainingOut, TrainingStateData, TrainingStatus
+from ..data_classes import (
+    Context,
+    Errors,
+    PretrainedModel,
+    Training,
+    TrainingOut,
+    TrainingStateData,
+    TrainingStatus,
+)
 from ..enums import TrainerState
-from ..helpers.misc import create_project_folder, delete_all_training_folders, is_valid_uuid4
+from ..helpers.misc import (
+    create_project_folder,
+    delete_all_training_folders,
+    is_valid_uuid4,
+)
 from .downloader import TrainingsDownloader
 from .exceptions import CriticalError, NodeNeedsRestartError
 from .io_helpers import ActiveTrainingIO, EnvironmentVars, LastTrainingIO
@@ -66,7 +78,7 @@ class TrainerLogicGeneric(ABC):
         return self._training
 
     @property
-    def hyperparameters(self) -> dict:
+    def hyperparameters(self) -> Dict[str, Any]:
         assert self._training is not None, 'Training should have data'
         return self._training.hyperparameters
 
@@ -357,6 +369,9 @@ class TrainerLogicGeneric(ABC):
         """Syncronizes the training with the Learning Loop via the update_training endpoint.
         NOTE: This stage sets the errors explicitly because it may be used inside the training stage.
         """
+        if not self.node.sio_client or not self.node.sio_client.connected:
+            raise ConnectionError('SocketIO client is not connected')
+
         error_key = 'sync_confusion_matrix'
         try:
             new_best_model = self._get_new_best_training_state()
